@@ -1,7 +1,9 @@
 import os
 import io
-import ujson as json
-import uvloop
+try:
+    import ujson as json
+except ImportError:
+    import json
 import asyncio
 
 from types import MappingProxyType
@@ -106,9 +108,12 @@ class AsyncBot(object):
             loop: Optional = None
     ):
 
-        # gc.disable()
         if loop is None:
-            asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
+            try:
+                import uvloop
+                asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
+            except ImportError:
+                pass
             self.loop = asyncio.new_event_loop()
         else:
             self.loop = loop
@@ -988,7 +993,6 @@ class AsyncBot(object):
 
     @staticmethod
     def loads(object, *args, **kwargs) -> MappingProxyType:
-
         return MappingProxyType(
             json.loads(object)
         )
